@@ -14,7 +14,7 @@ Usage::
     client: IoTDataPlaneClient = boto3.client("iot-data")
     session_client: IoTDataPlaneClient = session.client("iot-data")
 """
-from mypy_boto3_iot_data.client import IoTDataPlaneClient, IoTDataPlaneClient as Client
+from mypy_boto3_iot_data.client import IoTDataPlaneClient as Client, IoTDataPlaneClient
 
 
 __all__ = ("Client", "IoTDataPlaneClient")
